import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()


setuptools.setup(
    name="ziplineio",
    version="0.1.1",
    author="Cam Sima",
    author_email="cjsima@gmail.com",
    description="ASGI web framework ",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/CameronSima/ZipLine",
    packages=setuptools.find_packages("app"),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
